# Clean ENOA

This package makes requests to INEGI about unemployment in Mexico

[![codecov](https://codecov.io/gh/nepito/clean-enoa/branch/main/graph/badge.svg?token=DIoEtHqRMU)](https://codecov.io/gh/nepito/clean-enoa)
![example branch
parameter](https://github.com/nepito/clean-enoa/actions/workflows/actions.yml/badge.svg)
[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/)


## Environment Variables

To run this project, you will need to add the following environment variables to your `~/.profile`
file

`INEGI_TOKEN`

Get a token [here](http://www3.inegi.org.mx//sistemas/api/indicadores/v1/tokenVerify.aspx).

## Installation

Install clean_enoa with pip

```bash
  pip install clean_enoa
```

## Feedback

If you have any feedback, please reach out to us at nepo.rojas@islas.org.mx